@@ -1,6 +1,5 @@
 package Dancer::Template::Xslate;
 
-
 use strict;
 use warnings;
 
@@ -9,9 +8,9 @@ use Dancer::App;
 use File::Spec::Functions qw(abs2rel rel2abs);
 use Text::Xslate;
 
-use base 'Dancer::Template::Abstract';
+use base "Dancer::Template::Abstract";
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 # ABSTRACT: Text::Xslate wrapper for Dancer
 
 # Note: The standard Xslate template extension is
@@ -22,33 +21,38 @@ sub init {
     my $app    = Dancer::App->current;
     my %xslate_args = %{$self->config};
 
-    ## set default path for header/footer etc.
+    ## Set default path for header/footer etc.
     $xslate_args{path} ||= [];
-    my $views_dir = $app->setting('views');
-    push @{$xslate_args{path}}, $views_dir
-        if not grep { $_ eq $views_dir } @{$xslate_args{path}};
+    my $views_dir = $app->setting("views") || "";
+    push @{ $xslate_args{path} }, $views_dir
+        if !grep { $_ eq $views_dir } @{ $xslate_args{path} };
 
     ## for those who read Text::Xslate instead of Dancer::Template::Abstract
-    $self->config->{extension} = $xslate_args{suffix}
-        if exists $xslate_args{suffix};
+    if ( defined $xslate_args{suffix} ) {
+        $self->config->{extension} = $xslate_args{suffix};
+        $self->config->{extension} =~ s/^\.//;
+    }
 
-    ## avoid 'Text::Xslate: Unknown option(s): extension'
-    $xslate_args{suffix} = delete $xslate_args{extension}
-        if exists $xslate_args{extension};
+    ## Avoid "Text::Xslate: Unknown option(s): extension"
+    $xslate_args{suffix} = exists $xslate_args{extension}
+        ? delete $xslate_args{extension}
+        : ".tt";
+    $xslate_args{suffix} = ".$xslate_args{suffix}"
+        if $xslate_args{suffix} !~ /^\./;
 
     $self->{driver} = Text::Xslate->new(%xslate_args);
-    return;
+    return $self;
 }
 
 sub render {
     my ($self, $template, $tokens) = @_;
     my $app    = Dancer::App->current;
-    $template = abs2rel( rel2abs($template), $app->setting('views') );
+    $template = abs2rel( rel2abs($template), $app->setting("views") );
     my $xslate = $self->{driver};
     my $content = $xslate->render($template, $tokens);
 
     if (my $err = $@) {
-        croak qq[Couldn't render template "$err"];
+        croak qq(Couldn't render template "$err");
     }
 
     return $content;
@@ -66,7 +70,7 @@ Dancer::Template::Xslate - Text::Xslate wrapper for Dancer
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
@@ -91,9 +95,35 @@ You can configure L<Text::Xslate>:
         module:
           - Text::Xslate::Bridge::TT2Like # to keep partial compatibility with Template Toolkit
 
+=head1 CAVEATS
+
+=over
+
+=item Cascading
+
+Dancer already provides a <cascade>-like feature, called a "layout", in order
+to augment other template engines lacking such a feature. In order to use
+Xslate's C<cascade>, turn off C<layout> by commenting out or removing the
+appropriate line in your Dancer application config.
+
+=item Smart HTML Escaping
+
+Use of Dancer's C<layout> feature will cause HTML templates to be HTML-entity
+encoded twice if Xslate's "smart HTML escaping" feature is enabled. Xslate's
+C<type> option can be set to "text" to disable smart-escaping, or, once again,
+C<layout> can be disabled in favor of C<cascade>.
+
+=back
+
 =head1 SEE ALSO
 
-L<Dancer>, L<Text::Xslate>, L<http://xslate.org/>
+=over
+
+=item L<Dancer>
+
+=item L<Text::Xslate>
+
+=back
 
 =head1 AUTHOR
 
